@@ -10,6 +10,7 @@
 #include "namespaces.hh"
 #include "ednssubnet.hh"
 #include "lua-base4.hh"
+#include "ext/luawrapper/include/LuaContext.hpp"
 #include "dns_random.hh"
 
 BaseLua4::BaseLua4() {
@@ -32,16 +33,6 @@ void BaseLua4::loadString(const std::string &script) {
 //  By default no features
 void BaseLua4::getFeatures(Features &) { }
 
-#if !defined(HAVE_LUA)
-
-void BaseLua4::prepareContext() { return; }
-void BaseLua4::loadStream(std::istream &is) { return; }
-BaseLua4::~BaseLua4() { }
-
-#else
-
-#include "ext/luawrapper/include/LuaContext.hpp"
-
 void BaseLua4::prepareContext() {
   d_lw = std::unique_ptr<LuaContext>(new LuaContext);
 
@@ -183,7 +174,7 @@ void BaseLua4::prepareContext() {
   d_lw->registerFunction("match", (bool (NetmaskGroup::*)(const ComboAddress&) const)&NetmaskGroup::match);
 
   // DNSRecord
-  d_lw->writeFunction("newDR", [](const DNSName &name, const std::string &type, unsigned int ttl, const std::string &content, int place){ QType qtype; qtype = type; auto dr = DNSRecord(); dr.d_name = name; dr.d_type = qtype.getCode(); dr.d_ttl = ttl; dr.d_content = shared_ptr<DNSRecordContent>(DNSRecordContent::mastermake(dr.d_type, 1, content)); dr.d_place = static_cast<DNSResourceRecord::Place>(place); return dr; });
+  d_lw->writeFunction("newDR", [](const DNSName &name, const std::string &type, unsigned int ttl, const std::string &content, int place){ QType qtype; qtype = type; auto dr = DNSRecord(); dr.d_name = name; dr.d_type = qtype.getCode(); dr.d_ttl = ttl; dr.d_content = shared_ptr<DNSRecordContent>(DNSRecordContent::mastermake(dr.d_type, QClass::IN, content)); dr.d_place = static_cast<DNSResourceRecord::Place>(place); return dr; });
   d_lw->registerMember("name", &DNSRecord::d_name);
   d_lw->registerMember("type", &DNSRecord::d_type);
   d_lw->registerMember("ttl", &DNSRecord::d_ttl);
@@ -260,5 +251,3 @@ void BaseLua4::loadStream(std::istream &is) {
 }
 
 BaseLua4::~BaseLua4() { }
-
-#endif
